@@ -2,7 +2,7 @@ use std::num::NonZeroUsize;
 use std::ops::Deref;
 use std::path::{Path, PathBuf};
 use std::time::Duration;
-
+use uv_client::{DEFAULT_CONNECT_TIMEOUT, DEFAULT_READ_TIMEOUT, DEFAULT_READ_TIMEOUT_UPLOAD};
 use uv_dirs::{system_config_file, user_config_dir};
 use uv_flags::EnvironmentFlags;
 use uv_fs::Simplified;
@@ -623,9 +623,12 @@ pub struct EnvironmentOptions {
     pub install_mirrors: PythonInstallMirrors,
     pub log_context: Option<bool>,
     pub lfs: Option<bool>,
-    pub http_timeout: Duration,
+    pub http_connect_timeout: Duration,
+    pub http_read_timeout: Duration,
+    /// There's no upload timeout in reqwest, instead we have to use a read timeout as upload
+    /// timeout.
+    pub http_read_timeout_upload: Duration,
     pub http_retries: u32,
-    pub upload_http_timeout: Duration,
     pub concurrency: Concurrency,
     #[cfg(feature = "tracing-durations-export")]
     pub tracing_durations_file: Option<PathBuf>,
@@ -654,7 +657,7 @@ impl EnvironmentOptions {
     pub fn new() -> Result<Self, Error> {
         // Timeout options, matching https://doc.rust-lang.org/nightly/cargo/reference/config.html#httptimeout
         // `UV_REQUEST_TIMEOUT` is provided for backwards compatibility with v0.1.6
-        let http_timeout = parse_integer_environment_variable(
+        let http_read_timeout = parse_integer_environment_variable(
             EnvVars::UV_HTTP_TIMEOUT,
             Some("value should be an integer number of seconds"),
         )?
@@ -701,14 +704,20 @@ impl EnvironmentOptions {
             },
             log_context: parse_boolish_environment_variable(EnvVars::UV_LOG_CONTEXT)?,
             lfs: parse_boolish_environment_variable(EnvVars::UV_GIT_LFS)?,
-            upload_http_timeout: parse_integer_environment_variable(
+            http_read_timeout_upload: parse_integer_environment_variable(
                 EnvVars::UV_UPLOAD_HTTP_TIMEOUT,
                 Some("value should be an integer number of seconds"),
             )?
             .map(Duration::from_secs)
-            .or(http_timeout)
-            .unwrap_or(Duration::from_mins(15)),
-            http_timeout: http_timeout.unwrap_or(Duration::from_secs(30)),
+            .or(http_read_timeout)
+            .unwrap_or(DEFAULT_READ_TIMEOUT_UPLOAD),
+            http_read_timeout: http_read_timeout.unwrap_or(DEFAULT_READ_TIMEOUT),
+            http_connect_timeout: parse_integer_environment_variable(
+                EnvVars::UV_HTTP_CONNECT_TIMEOUT,
+                Some("value should be an integer number of seconds"),
+            )?
+            .map(Duration::from_secs)
+            .unwrap_or(DEFAULT_CONNECT_TIMEOUT),
             http_retries: parse_integer_environment_variable(EnvVars::UV_HTTP_RETRIES, None)?
                 .unwrap_or(uv_client::DEFAULT_RETRIES),
             #[cfg(feature = "tracing-durations-export")]
