@@ -3,6 +3,7 @@ use anyhow::{Context, Result};
 use std::env;
 use std::io::Write;
 use std::path::Path;
+use uv_preview::Preview;
 
 /// PEP 517 hook to build a source distribution.
 pub(crate) fn build_sdist(sdist_directory: &Path) -> Result<ExitStatus> {
@@ -21,6 +22,7 @@ pub(crate) fn build_sdist(sdist_directory: &Path) -> Result<ExitStatus> {
 pub(crate) fn build_wheel(
     wheel_directory: &Path,
     metadata_directory: Option<&Path>,
+    preview: Preview,
 ) -> Result<ExitStatus> {
     let filename = uv_build_backend::build_wheel(
         &env::current_dir()?,
@@ -28,6 +30,7 @@ pub(crate) fn build_wheel(
         metadata_directory,
         uv_version::version(),
         false,
+        preview,
     )?;
     // Tell the build frontend about the name of the artifact we built
     writeln!(&mut std::io::stdout(), "{filename}").context("stdout is closed")?;
@@ -38,6 +41,7 @@ pub(crate) fn build_wheel(
 pub(crate) fn build_editable(
     wheel_directory: &Path,
     metadata_directory: Option<&Path>,
+    preview: Preview,
 ) -> Result<ExitStatus> {
     let filename = uv_build_backend::build_editable(
         &env::current_dir()?,
@@ -45,6 +49,7 @@ pub(crate) fn build_editable(
         metadata_directory,
         uv_version::version(),
         false,
+        preview,
     )?;
     // Tell the build frontend about the name of the artifact we built
     writeln!(&mut std::io::stdout(), "{filename}").context("stdout is closed")?;
@@ -62,11 +67,15 @@ pub(crate) fn get_requires_for_build_wheel() -> Result<ExitStatus> {
 }
 
 /// PEP 517 hook to just emit metadata through `.dist-info`.
-pub(crate) fn prepare_metadata_for_build_wheel(metadata_directory: &Path) -> Result<ExitStatus> {
+pub(crate) fn prepare_metadata_for_build_wheel(
+    metadata_directory: &Path,
+    preview: Preview,
+) -> Result<ExitStatus> {
     let filename = uv_build_backend::metadata(
         &env::current_dir()?,
         metadata_directory,
         uv_version::version(),
+        preview,
     )?;
     // Tell the build frontend about the name of the artifact we built
     writeln!(&mut std::io::stdout(), "{filename}").context("stdout is closed")?;
@@ -79,11 +88,15 @@ pub(crate) fn get_requires_for_build_editable() -> Result<ExitStatus> {
 }
 
 /// PEP 660 hook to just emit metadata through `.dist-info`.
-pub(crate) fn prepare_metadata_for_build_editable(metadata_directory: &Path) -> Result<ExitStatus> {
+pub(crate) fn prepare_metadata_for_build_editable(
+    metadata_directory: &Path,
+    preview: Preview,
+) -> Result<ExitStatus> {
     let filename = uv_build_backend::metadata(
         &env::current_dir()?,
         metadata_directory,
         uv_version::version(),
+        preview,
     )?;
     // Tell the build frontend about the name of the artifact we built
     writeln!(&mut std::io::stdout(), "{filename}").context("stdout is closed")?;
