@@ -15,8 +15,7 @@ use uv_cache::{Cache, CacheBucket};
 use uv_client::{BaseClientBuilder, FlatIndexClient, RegistryClientBuilder};
 use uv_configuration::{
     BuildIsolation, BuildKind, BuildOptions, BuildOutput, Concurrency, Constraints,
-    DependencyGroupsWithDefaults, HashCheckingMode, IndexStrategy, KeyringProviderType,
-    SourceStrategy,
+    DependencyGroupsWithDefaults, HashCheckingMode, IndexStrategy, KeyringProviderType, NoSources,
 };
 use uv_dispatch::{BuildDispatch, SharedState};
 use uv_distribution::LoweredExtraBuildDependencies;
@@ -97,7 +96,7 @@ enum Error {
 }
 
 /// Build source distributions and wheels.
-#[allow(clippy::fn_params_excessive_bools)]
+#[expect(clippy::fn_params_excessive_bools)]
 pub(crate) async fn build_frontend(
     project_dir: &Path,
     src: Option<PathBuf>,
@@ -169,7 +168,9 @@ enum BuildResult {
     Success,
 }
 
-#[allow(clippy::fn_params_excessive_bools)]
+// https://github.com/rust-lang/rust/issues/147648
+#[allow(unused_assignments)]
+#[expect(clippy::fn_params_excessive_bools)]
 async fn build_impl(
     project_dir: &Path,
     src: Option<&Path>,
@@ -358,7 +359,7 @@ async fn build_impl(
             *index_strategy,
             *keyring_provider,
             exclude_newer.clone(),
-            *sources,
+            sources.clone(),
             concurrency,
             build_options,
             sdist,
@@ -441,7 +442,7 @@ async fn build_impl(
     }
 }
 
-#[allow(clippy::fn_params_excessive_bools)]
+#[expect(clippy::fn_params_excessive_bools)]
 async fn build_package(
     source: AnnotatedSource<'_>,
     output_dir: Option<&Path>,
@@ -467,7 +468,7 @@ async fn build_package(
     index_strategy: IndexStrategy,
     keyring_provider: KeyringProviderType,
     exclude_newer: ExcludeNewer,
-    sources: SourceStrategy,
+    sources: NoSources,
     concurrency: Concurrency,
     build_options: &BuildOptions,
     sdist: bool,
@@ -627,7 +628,7 @@ async fn build_package(
         build_options,
         &hasher,
         exclude_newer,
-        sources,
+        sources.clone(),
         workspace_cache,
         concurrency,
         preview,
@@ -687,7 +688,7 @@ async fn build_package(
                     printer,
                     "source distribution",
                     &build_dispatch,
-                    sources,
+                    &sources,
                     dist,
                     subdirectory,
                     version_id,
@@ -704,7 +705,7 @@ async fn build_package(
                 printer,
                 "source distribution",
                 &build_dispatch,
-                sources,
+                &sources,
                 dist,
                 subdirectory,
                 version_id,
@@ -742,6 +743,7 @@ async fn build_package(
                 version_id,
                 build_output,
                 Some(sdist_build.normalized_filename().version()),
+                preview,
             )
             .await?;
             build_results.push(wheel_build);
@@ -755,7 +757,7 @@ async fn build_package(
                 printer,
                 "source distribution",
                 &build_dispatch,
-                sources,
+                &sources,
                 dist,
                 subdirectory,
                 version_id,
@@ -779,6 +781,7 @@ async fn build_package(
                 version_id,
                 build_output,
                 None,
+                preview,
             )
             .await?;
             build_results.push(wheel_build);
@@ -792,7 +795,7 @@ async fn build_package(
                 printer,
                 "source distribution",
                 &build_dispatch,
-                sources,
+                &sources,
                 dist,
                 subdirectory,
                 version_id,
@@ -814,6 +817,7 @@ async fn build_package(
                 version_id,
                 build_output,
                 Some(sdist_build.normalized_filename().version()),
+                preview,
             )
             .await?;
             build_results.push(sdist_build);
@@ -857,6 +861,7 @@ async fn build_package(
                 version_id,
                 build_output,
                 version.as_ref(),
+                preview,
             )
             .await?;
             build_results.push(wheel_build);
@@ -899,7 +904,7 @@ async fn build_sdist(
     build_kind_message: &str,
     // Below is only used with PEP 517 builds
     build_dispatch: &BuildDispatch<'_>,
-    sources: SourceStrategy,
+    sources: &NoSources,
     dist: Option<&SourceDist>,
     subdirectory: Option<&Path>,
     version_id: Option<&str>,
@@ -908,11 +913,12 @@ async fn build_sdist(
     let build_result = match action {
         BuildAction::List => {
             let source_tree_ = source_tree.to_path_buf();
+            let sources_enabled = sources.is_none();
             let (filename, file_list) = tokio::task::spawn_blocking(move || {
                 uv_build_backend::list_source_dist(
                     &source_tree_,
                     uv_version::version(),
-                    sources == SourceStrategy::Enabled,
+                    sources_enabled,
                 )
             })
             .await??;
@@ -937,12 +943,13 @@ async fn build_sdist(
             )?;
             let source_tree = source_tree.to_path_buf();
             let output_dir_ = output_dir.to_path_buf();
+            let sources_enabled = sources.is_none();
             let filename = tokio::task::spawn_blocking(move || {
                 uv_build_backend::build_source_dist(
                     &source_tree,
                     &output_dir_,
                     uv_version::version(),
-                    sources == SourceStrategy::Enabled,
+                    sources_enabled,
                 )
             })
             .await??
@@ -1007,22 +1014,25 @@ async fn build_wheel(
     build_kind_message: &str,
     // Below is only used with PEP 517 builds
     build_dispatch: &BuildDispatch<'_>,
-    sources: SourceStrategy,
+    sources: NoSources,
     dist: Option<&SourceDist>,
     subdirectory: Option<&Path>,
     version_id: Option<&str>,
     build_output: BuildOutput,
     // Used for checking version consistency
     version: Option<&Version>,
+    preview: Preview,
 ) -> Result<BuildMessage, Error> {
     let build_message = match action {
         BuildAction::List => {
             let source_tree_ = source_tree.to_path_buf();
+            let sources_enabled = sources.is_none();
             let (filename, file_list) = tokio::task::spawn_blocking(move || {
                 uv_build_backend::list_wheel(
                     &source_tree_,
                     uv_version::version(),
-                    sources == SourceStrategy::Enabled,
+                    sources_enabled,
+                    preview,
                 )
             })
             .await??;
@@ -1047,13 +1057,15 @@ async fn build_wheel(
             )?;
             let source_tree = source_tree.to_path_buf();
             let output_dir_ = output_dir.to_path_buf();
+            let sources_enabled = sources.is_none();
             let filename = tokio::task::spawn_blocking(move || {
                 uv_build_backend::build_wheel(
                     &source_tree,
                     &output_dir_,
                     None,
                     uv_version::version(),
-                    sources == SourceStrategy::Enabled,
+                    sources_enabled,
+                    preview,
                 )
             })
             .await??;
@@ -1083,7 +1095,7 @@ async fn build_wheel(
                     source.path(),
                     version_id,
                     dist,
-                    sources,
+                    &sources,
                     BuildKind::Wheel,
                     build_output,
                     BuildStack::default(),
