@@ -2,14 +2,13 @@ use std::path::Path;
 use std::str::FromStr;
 
 use anyhow::{Context, Result};
-use reqwest_retry::policies::ExponentialBackoff;
 use tokio::process::Command;
 
 use uv_bin_install::{Binary, bin_install};
 use uv_cache::Cache;
-use uv_client::{BaseClientBuilder, retries_from_env};
+use uv_client::BaseClientBuilder;
 use uv_pep440::Version;
-use uv_preview::{Preview, PreviewFeatures};
+use uv_preview::{Preview, PreviewFeature};
 use uv_warnings::warn_user;
 use uv_workspace::{DiscoveryOptions, VirtualProject, WorkspaceCache, WorkspaceError};
 
@@ -32,10 +31,10 @@ pub(crate) async fn format(
     no_project: bool,
 ) -> Result<ExitStatus> {
     // Check if the format feature is in preview
-    if !preview.is_enabled(PreviewFeatures::FORMAT) {
+    if !preview.is_enabled(PreviewFeature::Format) {
         warn_user!(
             "`uv format` is experimental and may change without warning. Pass `--preview-features {}` to disable this warning.",
-            PreviewFeatures::FORMAT
+            PreviewFeature::Format
         );
     }
 
@@ -64,9 +63,9 @@ pub(crate) async fn format(
     // Parse version if provided
     let version = version.as_deref().map(Version::from_str).transpose()?;
 
+    let retry_policy = client_builder.retry_policy();
     // Python downloads are performing their own retries to catch stream errors, disable the
     // default retries to avoid the middleware from performing uncontrolled retries.
-    let retry_policy = ExponentialBackoff::builder().build_with_max_retries(retries_from_env()?);
     let client = client_builder.retries(0).build();
 
     // Get the path to Ruff, downloading it if necessary
