@@ -57,7 +57,7 @@ fn list_empty_json() {
 }
 
 #[test]
-#[cfg(feature = "pypi")]
+#[cfg(feature = "test-pypi")]
 fn list_single_no_editable() -> Result<()> {
     let context = TestContext::new("3.12");
 
@@ -98,7 +98,7 @@ fn list_single_no_editable() -> Result<()> {
 }
 
 #[test]
-#[cfg(feature = "pypi")]
+#[cfg(feature = "test-pypi")]
 fn list_outdated_columns() -> Result<()> {
     let context = TestContext::new("3.12");
 
@@ -139,7 +139,7 @@ fn list_outdated_columns() -> Result<()> {
 }
 
 #[test]
-#[cfg(feature = "pypi")]
+#[cfg(feature = "test-pypi")]
 fn list_outdated_json() -> Result<()> {
     let context = TestContext::new("3.12");
 
@@ -193,7 +193,7 @@ fn list_outdated_freeze() {
 }
 
 #[test]
-#[cfg(feature = "git")]
+#[cfg(feature = "test-git")]
 fn list_outdated_git() -> Result<()> {
     let context = TestContext::new("3.12");
 
@@ -236,7 +236,7 @@ fn list_outdated_git() -> Result<()> {
 }
 
 #[test]
-#[cfg(feature = "pypi")]
+#[cfg(feature = "test-pypi")]
 fn list_outdated_index() -> Result<()> {
     let context = TestContext::new("3.12");
 
@@ -280,7 +280,7 @@ fn list_outdated_index() -> Result<()> {
 }
 
 #[test]
-#[cfg(feature = "pypi")]
+#[cfg(feature = "test-pypi")]
 fn list_editable() {
     let context = TestContext::new("3.12");
 
@@ -326,7 +326,7 @@ fn list_editable() {
 }
 
 #[test]
-#[cfg(feature = "pypi")]
+#[cfg(feature = "test-pypi")]
 fn list_editable_only() {
     let context = TestContext::new("3.12");
 
@@ -401,7 +401,7 @@ fn list_editable_only() {
 }
 
 #[test]
-#[cfg(feature = "pypi")]
+#[cfg(feature = "test-pypi")]
 fn list_exclude() {
     let context = TestContext::new("3.12");
 
@@ -483,7 +483,7 @@ fn list_exclude() {
 }
 
 #[test]
-#[cfg(feature = "pypi")]
+#[cfg(feature = "test-pypi")]
 #[cfg(not(windows))]
 fn list_format_json() {
     let context = TestContext::new("3.12");
@@ -550,7 +550,7 @@ fn list_format_json() {
 }
 
 #[test]
-#[cfg(feature = "pypi")]
+#[cfg(feature = "test-pypi")]
 fn list_format_freeze() {
     let context = TestContext::new("3.12");
 
@@ -716,7 +716,7 @@ Version: 0.1-bulbasaur
 }
 
 #[test]
-#[cfg(feature = "pypi")]
+#[cfg(feature = "test-pypi")]
 fn list_ignores_quiet_flag_format_freeze() {
     let context = TestContext::new("3.12");
 
@@ -791,7 +791,7 @@ fn list_ignores_quiet_flag_format_freeze() {
 }
 
 #[test]
-#[cfg(feature = "pypi")]
+#[cfg(feature = "test-pypi")]
 fn list_target() -> Result<()> {
     let context = TestContext::new("3.12");
 
@@ -840,7 +840,7 @@ fn list_target() -> Result<()> {
 }
 
 #[test]
-#[cfg(feature = "pypi")]
+#[cfg(feature = "test-pypi")]
 fn list_prefix() -> Result<()> {
     let context = TestContext::new("3.12");
 
