@@ -981,7 +981,7 @@ fn python_find_managed() {
 /// used in the test context.
 #[test]
 #[cfg(unix)]
-#[cfg(feature = "python-managed")]
+#[cfg(feature = "test-python-managed")]
 fn python_required_python_major_minor() {
     let context: TestContext = TestContext::new_with_versions(&["3.11", "3.12"]);
 
@@ -1248,7 +1248,7 @@ fn python_find_path() {
 }
 
 #[test]
-#[cfg(feature = "python-managed")]
+#[cfg(feature = "test-python-managed")]
 fn python_find_freethreaded_313() {
     let context: TestContext = TestContext::new_with_versions(&[])
         .with_filtered_python_keys()
@@ -1288,7 +1288,7 @@ fn python_find_freethreaded_313() {
 }
 
 #[test]
-#[cfg(feature = "python-managed")]
+#[cfg(feature = "test-python-managed")]
 fn python_find_freethreaded_314() {
     let context: TestContext = TestContext::new_with_versions(&[])
         .with_filtered_python_keys()
@@ -1366,7 +1366,7 @@ fn python_find_freethreaded_314() {
 }
 
 #[test]
-#[cfg(feature = "python-managed")]
+#[cfg(feature = "test-python-managed")]
 fn python_find_prerelease_version_specifiers() {
     let context: TestContext = TestContext::new_with_versions(&[])
         .with_filtered_python_keys()
@@ -1381,7 +1381,7 @@ fn python_find_prerelease_version_specifiers() {
     context.python_install().arg("3.14.0rc3").assert().success();
 
     // `>=3.14` should allow pre-release versions
-    uv_snapshot!(context.filters(), context.python_find().arg(">=3.14"), @"
+    uv_snapshot!(context.filters(), context.python_find().arg(">=3.14").arg("--resolve-links"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -1392,7 +1392,7 @@ fn python_find_prerelease_version_specifiers() {
     ");
 
     // `>3.14rc2` should not match rc2
-    uv_snapshot!(context.filters(), context.python_find().arg(">3.14.0rc2"), @"
+    uv_snapshot!(context.filters(), context.python_find().arg(">3.14.0rc2").arg("--resolve-links"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -1412,7 +1412,7 @@ fn python_find_prerelease_version_specifiers() {
     ");
 
     // `>=3.14.0rc3` should match rc3
-    uv_snapshot!(context.filters(), context.python_find().arg(">=3.14.0rc3"), @"
+    uv_snapshot!(context.filters(), context.python_find().arg(">=3.14.0rc3").arg("--resolve-links"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -1422,7 +1422,7 @@ fn python_find_prerelease_version_specifiers() {
     ");
 
     // `<3.14.0rc3` should match rc2
-    uv_snapshot!(context.filters(), context.python_find().arg("<3.14.0rc3"), @"
+    uv_snapshot!(context.filters(), context.python_find().arg("<3.14.0rc3").arg("--resolve-links"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -1432,7 +1432,7 @@ fn python_find_prerelease_version_specifiers() {
     ");
 
     // `<=3.14.0rc3` should match rc3
-    uv_snapshot!(context.filters(), context.python_find().arg("<=3.14.0rc3"), @"
+    uv_snapshot!(context.filters(), context.python_find().arg("<=3.14.0rc3").arg("--resolve-links"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -1445,7 +1445,7 @@ fn python_find_prerelease_version_specifiers() {
     context.python_install().arg("3.14.0").assert().success();
 
     // `>=3.14` should prefer stable
-    uv_snapshot!(context.filters(), context.python_find().arg(">=3.14"), @"
+    uv_snapshot!(context.filters(), context.python_find().arg(">=3.14").arg("--resolve-links"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -1455,7 +1455,7 @@ fn python_find_prerelease_version_specifiers() {
     ");
 
     // `>3.14rc2` should prefer stable
-    uv_snapshot!(context.filters(), context.python_find().arg(">3.14.0rc2"), @"
+    uv_snapshot!(context.filters(), context.python_find().arg(">3.14.0rc2").arg("--resolve-links"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -1466,7 +1466,7 @@ fn python_find_prerelease_version_specifiers() {
 }
 
 #[test]
-#[cfg(feature = "python-managed")]
+#[cfg(feature = "test-python-managed")]
 fn python_find_prerelease_with_patch_request() {
     let context: TestContext = TestContext::new_with_versions(&[])
         .with_filtered_python_keys()
@@ -1485,7 +1485,7 @@ fn python_find_prerelease_with_patch_request() {
     success: true
     exit_code: 0
     ----- stdout -----
-    [TEMP_DIR]/managed/cpython-3.14.0rc3-[PLATFORM]/[INSTALL-BIN]/[PYTHON]
+    [TEMP_DIR]/managed/cpython-3.14-[PLATFORM]/[INSTALL-BIN]/[PYTHON]
 
     ----- stderr -----
     warning: You're using a pre-release version of Python (3.14.0rc3) but a stable version is available. Use `uv python upgrade 3.14` to upgrade.
