@@ -16,7 +16,7 @@ fn python_upgrade() {
         .with_filtered_latest_python_versions();
 
     // Install an earlier patch version
-    uv_snapshot!(context.filters(), context.python_install().arg("--preview").arg("3.10.17"), @"
+    uv_snapshot!(context.filters(), context.python_install().arg("3.10.17"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -27,7 +27,7 @@ fn python_upgrade() {
     ");
 
     // Don't accept patch version as argument to upgrade command
-    uv_snapshot!(context.filters(), context.python_upgrade().arg("--preview").arg("3.10.17"), @"
+    uv_snapshot!(context.filters(), context.python_upgrade().arg("3.10.17"), @"
     success: false
     exit_code: 1
     ----- stdout -----
@@ -37,7 +37,7 @@ fn python_upgrade() {
     ");
 
     // Upgrade patch version
-    uv_snapshot!(context.filters(), context.python_upgrade().arg("--preview").arg("3.10"), @"
+    uv_snapshot!(context.filters(), context.python_upgrade().arg("3.10"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -48,7 +48,7 @@ fn python_upgrade() {
     ");
 
     // Should be a no-op when already upgraded
-    uv_snapshot!(context.filters(), context.python_upgrade().arg("--preview").arg("3.10"), @"
+    uv_snapshot!(context.filters(), context.python_upgrade().arg("3.10"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -58,7 +58,7 @@ fn python_upgrade() {
     ");
 
     // Should reinstall on `--reinstall`
-    uv_snapshot!(context.filters(), context.python_upgrade().arg("--preview").arg("3.10").arg("--reinstall"), @"
+    uv_snapshot!(context.filters(), context.python_upgrade().arg("3.10").arg("--reinstall"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -86,7 +86,6 @@ fn python_upgrade() {
     ----- stdout -----
 
     ----- stderr -----
-    warning: `uv python upgrade` is experimental and may change without warning. Pass `--preview-features python-upgrade` to disable this warning
     Installed Python 3.14.[LATEST] in [TIME]
      + cpython-3.14.[LATEST]-[PLATFORM] (python3.14)
     ");
@@ -101,7 +100,7 @@ fn python_upgrade_without_version() {
         .with_managed_python_dirs();
 
     // Should be a no-op when no versions have been installed
-    uv_snapshot!(context.filters(), context.python_upgrade().arg("--preview"), @"
+    uv_snapshot!(context.filters(), context.python_upgrade(), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -111,7 +110,7 @@ fn python_upgrade_without_version() {
     ");
 
     // Install earlier patch versions for different minor versions
-    uv_snapshot!(context.filters(), context.python_install().arg("--preview").arg("3.11.8").arg("3.12.8").arg("3.13.1"), @"
+    uv_snapshot!(context.filters(), context.python_install().arg("3.11.8").arg("3.12.8").arg("3.13.1"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -127,7 +126,7 @@ fn python_upgrade_without_version() {
     filters.push((r"3.13.\d+", "3.13.[X]"));
 
     // Upgrade one patch version
-    uv_snapshot!(filters, context.python_upgrade().arg("--preview").arg("3.13"), @"
+    uv_snapshot!(filters, context.python_upgrade().arg("3.13"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -139,7 +138,7 @@ fn python_upgrade_without_version() {
 
     // Providing no minor version to `uv python upgrade` should upgrade the rest
     // of the patch versions
-    uv_snapshot!(context.filters(), context.python_upgrade().arg("--preview"), @"
+    uv_snapshot!(context.filters(), context.python_upgrade(), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -151,7 +150,7 @@ fn python_upgrade_without_version() {
     ");
 
     // Should be a no-op when every version is already upgraded
-    uv_snapshot!(context.filters(), context.python_upgrade().arg("--preview"), @"
+    uv_snapshot!(context.filters(), context.python_upgrade(), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -170,7 +169,7 @@ fn python_upgrade_transparent_from_venv() {
         .with_managed_python_dirs();
 
     // Install an earlier patch version
-    uv_snapshot!(context.filters(), context.python_install().arg("--preview").arg("3.10.17"), @"
+    uv_snapshot!(context.filters(), context.python_install().arg("3.10.17"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -228,7 +227,7 @@ fn python_upgrade_transparent_from_venv() {
     );
 
     // Upgrade patch version
-    uv_snapshot!(context.filters(), context.python_upgrade().arg("--preview").arg("3.10"), @"
+    uv_snapshot!(context.filters(), context.python_upgrade().arg("3.10"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -262,8 +261,8 @@ fn python_upgrade_transparent_from_venv() {
     );
 }
 
-// Installing Python in preview mode should not prevent virtual environments
-// from transparently upgrading.
+// Installing Python should not prevent virtual environments from transparently
+// upgrading.
 #[test]
 fn python_upgrade_transparent_from_venv_preview() {
     let context: TestContext = TestContext::new_with_versions(&["3.13"])
@@ -272,8 +271,8 @@ fn python_upgrade_transparent_from_venv_preview() {
         .with_filtered_exe_suffix()
         .with_managed_python_dirs();
 
-    // Install an earlier patch version using `--preview`
-    uv_snapshot!(context.filters(), context.python_install().arg("3.10.17").arg("--preview"), @"
+    // Install an earlier patch version
+    uv_snapshot!(context.filters(), context.python_install().arg("3.10.17"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -306,7 +305,7 @@ fn python_upgrade_transparent_from_venv_preview() {
     );
 
     // Upgrade patch version
-    uv_snapshot!(context.filters(), context.python_upgrade().arg("--preview").arg("3.10"), @"
+    uv_snapshot!(context.filters(), context.python_upgrade().arg("3.10"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -337,7 +336,7 @@ fn python_upgrade_ignored_with_python_pin() {
         .with_managed_python_dirs();
 
     // Install an earlier patch version
-    uv_snapshot!(context.filters(), context.python_install().arg("--preview").arg("3.10.17"), @"
+    uv_snapshot!(context.filters(), context.python_install().arg("3.10.17"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -370,7 +369,7 @@ fn python_upgrade_ignored_with_python_pin() {
     ");
 
     // Upgrade patch version
-    uv_snapshot!(context.filters(), context.python_upgrade().arg("--preview").arg("3.10"), @"
+    uv_snapshot!(context.filters(), context.python_upgrade().arg("3.10"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -403,7 +402,7 @@ fn python_no_transparent_upgrade_with_venv_patch_specification() {
         .with_managed_python_dirs();
 
     // Install an earlier patch version
-    uv_snapshot!(context.filters(), context.python_install().arg("--preview").arg("3.10.17"), @"
+    uv_snapshot!(context.filters(), context.python_install().arg("3.10.17"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -436,7 +435,7 @@ fn python_no_transparent_upgrade_with_venv_patch_specification() {
     );
 
     // Upgrade patch version
-    uv_snapshot!(context.filters(), context.python_upgrade().arg("--preview").arg("3.10"), @"
+    uv_snapshot!(context.filters(), context.python_upgrade().arg("3.10"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -470,7 +469,7 @@ fn python_transparent_upgrade_venv_venv() {
         .with_managed_python_dirs();
 
     // Install an earlier patch version
-    uv_snapshot!(context.filters(), context.python_install().arg("--preview").arg("3.10.17"), @"
+    uv_snapshot!(context.filters(), context.python_install().arg("3.10.17"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -528,7 +527,7 @@ fn python_transparent_upgrade_venv_venv() {
     );
 
     // Upgrade patch version
-    uv_snapshot!(context.filters(), context.python_upgrade().arg("--preview").arg("3.10"), @"
+    uv_snapshot!(context.filters(), context.python_upgrade().arg("3.10"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -566,7 +565,7 @@ fn python_upgrade_transparent_from_venv_module() {
     let bin_dir = context.temp_dir.child("bin");
 
     // Install earlier patch version
-    uv_snapshot!(context.filters(), context.python_install().arg("--preview").arg("3.12.9"), @"
+    uv_snapshot!(context.filters(), context.python_install().arg("3.12.9"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -597,7 +596,7 @@ fn python_upgrade_transparent_from_venv_module() {
     );
 
     // Upgrade patch version
-    uv_snapshot!(context.filters(), context.python_upgrade().arg("--preview").arg("3.12"), @"
+    uv_snapshot!(context.filters(), context.python_upgrade().arg("3.12"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -634,7 +633,7 @@ fn python_upgrade_transparent_from_venv_module_in_venv() {
     let bin_dir = context.temp_dir.child("bin");
 
     // Install earlier patch version
-    uv_snapshot!(context.filters(), context.python_install().arg("--preview").arg("3.10.17"), @"
+    uv_snapshot!(context.filters(), context.python_install().arg("3.10.17"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -683,7 +682,7 @@ fn python_upgrade_transparent_from_venv_module_in_venv() {
     );
 
     // Upgrade patch version
-    uv_snapshot!(context.filters(), context.python_upgrade().arg("--preview").arg("3.10"), @"
+    uv_snapshot!(context.filters(), context.python_upgrade().arg("3.10"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -725,7 +724,7 @@ fn python_upgrade_force_install() -> Result<()> {
         .touch()?;
 
     // Try to upgrade with a non-managed interpreter installed in `bin`.
-    uv_snapshot!(context.filters(), context.python_upgrade().arg("--preview").arg("3.12"), @"
+    uv_snapshot!(context.filters(), context.python_upgrade().arg("3.12"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -737,7 +736,7 @@ fn python_upgrade_force_install() -> Result<()> {
     ");
 
     // Force the `bin` install.
-    uv_snapshot!(context.filters(), context.python_install().arg("3.12").arg("--force").arg("--preview").arg("3.12"), @"
+    uv_snapshot!(context.filters(), context.python_install().arg("3.12").arg("--force").arg("3.12"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -769,7 +768,6 @@ fn python_upgrade_implementation() {
     ----- stdout -----
 
     ----- stderr -----
-    warning: `uv python upgrade` is experimental and may change without warning. Pass `--preview-features python-upgrade` to disable this warning
     All versions already on latest supported patch release
     ");
 }
@@ -783,7 +781,7 @@ fn python_upgrade_build_version() {
         .with_managed_python_dirs();
 
     // Install Python 3.12
-    uv_snapshot!(context.filters(), context.python_install().arg("--preview").arg("3.12"), @"
+    uv_snapshot!(context.filters(), context.python_install().arg("3.12"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -794,7 +792,7 @@ fn python_upgrade_build_version() {
     ");
 
     // Should be a no-op when already installed at latest version
-    uv_snapshot!(context.filters(), context.python_upgrade().arg("--preview").arg("3.12"), @"
+    uv_snapshot!(context.filters(), context.python_upgrade().arg("3.12"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -812,7 +810,7 @@ fn python_upgrade_build_version() {
     fs_err::write(&build_file, "19000101").unwrap();
 
     // Now upgrade should detect the outdated build version and reinstall
-    uv_snapshot!(context.filters(), context.python_upgrade().arg("--preview").arg("3.12"), @"
+    uv_snapshot!(context.filters(), context.python_upgrade().arg("3.12"), @"
     success: true
     exit_code: 0
     ----- stdout -----
@@ -823,7 +821,7 @@ fn python_upgrade_build_version() {
     ");
 
     // Should be a no-op again after upgrade
-    uv_snapshot!(context.filters(), context.python_upgrade().arg("--preview").arg("3.12"), @"
+    uv_snapshot!(context.filters(), context.python_upgrade().arg("3.12"), @"
     success: true
     exit_code: 0
     ----- stdout -----
